@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-09-28'; # DATE
-our $VERSION = '1.61'; # VERSION
+our $DATE = '2016-10-26'; # DATE
+our $VERSION = '1.62'; # VERSION
 
 use 5.010001;
 use strict;
@@ -481,14 +481,13 @@ sub _read_env {
         require Complete::Bash;
         ($words, undef) = @{ Complete::Bash::parse_cmdline($env, 0) };
     } elsif ($r->{shell} eq 'fish') {
-        require Complete::Fish;
-        ($words, undef) = @{ Complete::Fish::parse_cmdline($env) };
+        ($words, undef) = @{ Complete::Base::parse_cmdline($env) };
     } elsif ($r->{shell} eq 'tcsh') {
         require Complete::Tcsh;
         ($words, undef) = @{ Complete::Tcsh::parse_cmdline($env) };
     } elsif ($r->{shell} eq 'zsh') {
-        require Complete::Zsh;
-        ($words, undef) = @{ Complete::Zsh::parse_cmdline($env) };
+        require Complete::Bash;
+        ($words, undef) = @{ Complete::Bash::parse_cmdline($env) };
     } else {
         die "Unsupported shell '$r->{shell}'";
     }
@@ -509,14 +508,14 @@ sub do_completion {
         ($words, $cword) = @{ Complete::Bash::join_wordbreak_words($words, $cword) };
         $words = [map {Encode::decode('UTF-8', $_)} @$words];
     } elsif ($r->{shell} eq 'fish') {
-        require Complete::Fish;
-        ($words, $cword) = @{ Complete::Fish::parse_cmdline() };
+        require Complete::Bash;
+        ($words, $cword) = @{ Complete::Bash::parse_cmdline() };
     } elsif ($r->{shell} eq 'tcsh') {
         require Complete::Tcsh;
         ($words, $cword) = @{ Complete::Tcsh::parse_cmdline() };
     } elsif ($r->{shell} eq 'zsh') {
-        require Complete::Zsh;
-        ($words, $cword) = @{ Complete::Zsh::parse_cmdline() };
+        require Complete::Bash;
+        ($words, $cword) = @{ Complete::Bash::parse_cmdline() };
     } else {
         die "Unsupported shell '$r->{shell}'";
     }
@@ -587,13 +586,17 @@ sub do_completion {
 
     my $formatted;
     if ($r->{shell} eq 'bash') {
+        require Complete::Bash;
         $formatted = Complete::Bash::format_completion(
             $compres, {word=>$words->[$cword]});
     } elsif ($r->{shell} eq 'fish') {
+        require Complete::Fish;
         $formatted = Complete::Fish::format_completion($compres);
     } elsif ($r->{shell} eq 'tcsh') {
+        require Complete::Tcsh;
         $formatted = Complete::Tcsh::format_completion($compres);
     } elsif ($r->{shell} eq 'zsh') {
+        require Complete::Zsh;
         $formatted = Complete::Zsh::format_completion($compres);
     }
 
@@ -1444,7 +1447,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.61 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-28.
+This document describes version 1.62 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-10-26.
 
 =head1 DESCRIPTION
 
