@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-09-28'; # DATE
-our $VERSION = '1.61'; # VERSION
+our $DATE = '2016-10-26'; # DATE
+our $VERSION = '1.62'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -440,7 +440,8 @@ sub action_help {
 
     # hide usage '--subcommands' if we have subcommands but user has specified a
     # subcommand to use
-    my $has_sc_no_sc = $self->subcommands && !length($r->{subcommand_name});
+    my $has_sc_no_sc = $self->subcommands &&
+        !length($r->{subcommand_name} // '');
     delete $common_opts->{subcommands} if $self->subcommands && !$has_sc_no_sc;
 
     my $res = Perinci::CmdLine::Help::gen_help(
@@ -504,7 +505,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.61 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-09-28.
+This document describes version 1.62 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-10-26.
 
 =head1 SYNOPSIS
 
